@@ -14,9 +14,9 @@ from . import dtslogger
 from .commands_ import (
     _get_commands,
     _init_commands,
-    check_commands_outdated,
+    _ensure_commands_exist,
+    _ensure_commands_updated,
     InvalidRemote,
-    update_commands,
 )
 from .config import (
     get_config_path,
@@ -33,6 +33,9 @@ from .logging import dts_print
 from .version_check import check_if_outdated
 
 
+BILLBOARDS_VERSION: str = "v1"
+
+
 @dataclass
 class CommandsInfo:
     commands_path: str  # commands path
@@ -105,6 +108,7 @@ class DTShell(Cmd):
         # init commands
         cmds_just_initialized = False
 
+        # check if the commands path exists
         if exists(commands_path) and isfile(commands_path):
             remove(commands_path)
         if not exists(commands_path):
@@ -133,12 +137,12 @@ class DTShell(Cmd):
             and not self.local_commands_info.leave_alone
             and "update" not in sys.argv
         ):
-            check_commands_outdated(self.commands_path, self.repo_info)
+            self.update_commands()
 
         # show billboard (if any)
         billboard: Optional[str] = self.get_billboard()
         if billboard:
-            print(self.get_billboard())
+            print(billboard)
 
         self.reload_commands()
 
@@ -328,7 +332,8 @@ class DTShell(Cmd):
     @staticmethod
     def get_billboard() -> Optional[str]:
         # find billboards directory
-        billboard_dir: str = os.path.join(os.path.expanduser(DTShellConstants.ROOT), "billboards")
+        dts_dir: str = os.path.expanduser(DTShellConstants.ROOT)
+        billboard_dir: str = os.path.join(dts_dir, "billboards", BILLBOARDS_VERSION)
         if (not os.path.exists(billboard_dir)) or (not os.path.isdir(billboard_dir)):
             return None
         # get all sources of ads from the billboards directory
@@ -347,7 +352,10 @@ class DTShell(Cmd):
         return content
 
     def update_commands(self) -> bool:
-        return update_commands(self.commands_path, self.repo_info)
+        # check that the repo is initialized in the commands path
+        _ensure_commands_exist(self.commands_path, self.repo_info)
+        # update the commands if they are outdated
+        return _ensure_commands_updated(self.commands_path, self.repo_info)
 
 
 def _touch(path: str) -> None:
